#!/bin/bash

#author				: hennes (jm@rapidrabbit.de) -> original build-script by Michael Verret (AxXium)
#last changed		: 01-august-2007

#package			: bumprace
#homepgae			: http://user.cs.tu-berlin.de/~karlb/bumprace/
#source location	: http://user.cs.tu-berlin.de/~karlb/bumprace/bumprace-1.5.3.tar.gz
#dependencies		: coreutils,directfb,expat,fontconfig,freetype,gcc,gcc-g++,libdrm,libjpeg,libpng,libtiff,mesa,ncurses,perl,sdl,sysfsutils,xorg,xterm,zlib

# ----- credentials
softname="bumprace"
softversion="1.5.3"
srcurl="http://user.cs.tu-berlin.de/~karlb/bumprace/bumprace-1.5.3.tar.gz"
arch=i486
cpu=i686
build="1"
zenversion="48"
packageversion="$zenversion.$build"

# ----- verify script
if [ "$(id -u)" != "0" ]; then
			echo "Please run as root!"
			exit 0
fi

# ----- help
if [ "${1}" = "--help" ]; then
	echo \
"$softname ZenBuild

usage:	--help 		Display this text
	--cleanup	Clean up after creating the package
"
	exit 0
fi

# ----- build parameters
numjobs="-j3"
builddir="$(pwd)"
package="$softname-$softversion-$arch-$packageversion"

# ----- prepare directories
dest="$builddir/$package"
rm -rf $dest
prefix="/usr"
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/share/icons/hicolor/64x64/apps
mkdir -p $dest/usr/share/icons/hicolor/72x72/apps
mkdir -p $dest/usr/share/icons/hicolor/128x128/apps
mkdir -p $dest/usr/doc
destsrc="$dest/usr/src/$softname-$softversion"
mkdir -p $destsrc

# ----- make slack-desc-file
cat << EOF > $dest/install/slack-desc
        |-----handy-ruler------------------------------------------------------|
bumprace: bumprace (arcade racer)
bumprace:
bumprace: Bumprace is a simple arcade game. You've to get from the start to
bumprace: the finish line without crashing into deadly blocks. This game has
bumprace: really simple rules!
bumprace:
bumprace:
bumprace:
bumprace:
bumprace:
bumprace:
EOF

# ----- extract source-archive
srcdir=$softname-$softversion
rm -rf $srcdir
if [ -f $softname-$softversion.tar.gz ]; then
   echo "looking for source-file .. found"
else
   echo "looking for source-file .. none found"
   wget -c $srcurl
fi
tar -zxvf $softname-$softversion.tar.gz
cd $srcdir

# ----- create package-dependent directories
mkdir -p $dest/usr/doc/$srcdir

# ----- set target-permissions
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;

# ----- configure
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
	--prefix=$prefix \
	--disable-debug
	
# ----- make
make $numjobs
	
# ----- make install
make install DESTDIR=$dest

# ----- add default-files
cp -a \
	AUTHORS COPYING ChangeLog FAQ INSTALL NEWS README \
	$dest/usr/doc/$srcdir

# ----- treat icon-files
cd $builddir
tar -jxvf icons.tar.bz2 --directory=$builddir
cp icon-bumprace-48.png $dest/usr/share/icons/hicolor/48x48/apps/bumprace.png
cp icon-bumprace-64.png $dest/usr/share/icons/hicolor/64x64/apps/bumprace.png
cp icon-bumprace-72.png $dest/usr/share/icons/hicolor/72x72/apps/bumprace.png
cp icon-bumprace-128.png $dest/usr/share/icons/hicolor/128x128/apps/bumprace.png
cp icons.tar.bz2 $destsrc

# ----- make .desktop-file
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=BumpRace
Comment=Arcade Racing Game
Exec=bumprace
Icon=bumprace
Terminal=false
Type=Application
Categories=Game;ArcadeGame;
Encoding=UTF-8
EOF

# ----- copy build-file
cp "$builddir/build-$softname.sh" "$destsrc/build-$softname.sh"
chmod a+x "$destsrc/build-$softname.sh"

# ----- get-source-script
cat << EOF > "$destsrc/getsrc.sh"
wget -c $srcurl
EOF

chmod a+x "$destsrc/getsrc.sh"

# ----- post-build processing
cd $dest
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
	
# ----- packaging
chown -R root.root $dest/usr/bin
cd $dest
makepkg -l y -c n $dest.tgz
cd ..
md5sum $package.tgz > $package.md5
cat << "EOF" > $builddir/$package.dep
coreutils,directfb,expat,fontconfig,freetype,gcc,gcc-g++,libdrm,libjpeg,libpng,libtiff,mesa,ncurses,perl,sdl,sysfsutils,xorg,xterm,zlib
EOF

# ----- cleaning up
if [ "${1}" = "--cleanup" ]; then
rm -r $dest
rm -r $builddir/$srcdir
fi
